::: evalica.InsufficientRatingsError
::: evalica.LengthMismatchError
::: evalica.ScoreDimensionError
::: evalica.SolverError
::: evalica.RustExtensionWarning
    options:
      filters:
      - "!^__"
::: evalica.UnknownDistanceError
